@@ -46,7 +46,7 @@ from devinstaller_core.module_phony import ModulePhony
 
 
 class TypeModuleInstallInstruction(TypedDict, total=False):
-    """Type declaration for the instruction for `init`, `command` and `config`
+    """Type declaration for the instruction for `inits`, `command` and `configs`
     """
 
     cmd: str
@@ -67,25 +67,27 @@ class TypeCommonModule(TypedDict, total=False):
     alias: str
     commands: List[Union[TypeModuleInstallInstruction, str]]
     install_inst: List[TypeModuleInstallInstruction]
-    config: List[Union[TypeModuleInstallInstruction, str]]
+    configs: List[Union[TypeModuleInstallInstruction, str]]
     content: str
     create: bool
     description: str
     display: str
     executable: str
-    init: List[Union[TypeModuleInstallInstruction, str]]
+    inits: List[Union[TypeModuleInstallInstruction, str]]
     module_type: str
     name: str
     optionals: List[str]
     owner: str
-    parent_dir: str
+    file_path: str
+    folder_path: str
+    group: str
     permission: str
     requires: List[str]
     rollback: bool
     source: str
     supported_platforms: List[str]
     symbolic: bool
-    target: str
+    dest: str
     url: str
     version: str
     before: Optional[str]
@@ -171,7 +173,7 @@ class TypeValidateResponse(TypedDict):
     """
 
     valid: bool
-    document: Dict[Any, Any]
+    document: Dict[str, Any]
     errors: Dict[Any, Any]
 
 
@@ -195,7 +197,7 @@ TypeAnyModule = Union[
 TypeModuleMap = Dict[str, TypeAnyModule]
 
 ModuleInstallStatus = ["success", "failed", "in progress"]
-"""Status allowed for each modules. None is also included in Moduel status
+"""Status allowed for each modules. None is also included in Module status
 
 Values allowed:
     1. `success`
@@ -203,18 +205,26 @@ Values allowed:
     3. `in progress`
 """
 
-ModuleInstallInstructionKeys = Literal["init", "commands", "config"]
+ModuleInstallInstructionKeys = Literal["inits", "commands", "configs"]
 """These are the keys allowed for converting installation steps into
 `ModuleInstallInstruction` object
 
 Values allowed:
-    1. `init`
+    1. `inits`
     2. `commands`
-    3. `config`
+    3. `configs`
 """
 
 
 def convert_to_instruction_dict(installation_str: str) -> Dict[str, str]:
+    """Convert given string to dict.
+
+    Args:
+        installation_str (str): The string to be converted.
+
+    Returns:
+        Dict[str, str]: Expected dict
+    """
     return {"cmd": installation_str}
 
 
@@ -248,11 +258,10 @@ def module() -> Dict[str, Any]:
                 },
                 "alias": {"type": "string"},
                 "create": {"type": "boolean"},
-                "init": {
+                "inits": {
                     "type": "list",
                     "schema": {
                         "type": "dict",
-                        "coerce": (str, convert_to_instruction_dict),
                         "schema": {
                             "cmd": {"type": "string", "required": True},
                             "rollback": {"type": "string"},
@@ -263,18 +272,16 @@ def module() -> Dict[str, Any]:
                     "type": "list",
                     "schema": {
                         "type": "dict",
-                        "coerce": (str, convert_to_instruction_dict),
                         "schema": {
                             "cmd": {"type": "string", "required": True},
                             "rollback": {"type": "string"},
                         },
                     },
                 },
-                "config": {
+                "configs": {
                     "type": "list",
                     "schema": {
                         "type": "dict",
-                        "coerce": (str, convert_to_instruction_dict),
                         "schema": {
                             "cmd": {"type": "string", "required": True},
                             "rollback": {"type": "string"},
@@ -291,26 +298,29 @@ def module() -> Dict[str, Any]:
                     },
                 },
                 "uninstall_inst": {"type": "list", "schema": {"type": "string"}},
-                "content": {
-                    "type": "dict",
-                    "schema": {
-                        "digest": {"type": "string"},
-                        "path": {"type": "string"},
-                    },
-                },
+                # "content": {
+                #     "type": "dict",
+                #     "schema": {
+                #         "digest": {"type": "string"},
+                #         "path": {"type": "string"},
+                #     },
+                # },
+                "content": {"type": "string"},
                 "description": {"type": "string"},
                 "display": {"type": "string"},
                 "executable": {"type": "string"},
                 "name": {"type": "string", "required": True},
                 "optionals": {"type": "list", "schema": {"type": "string"}},
                 "owner": {"type": "string"},
-                "parent_dir": {"type": "string"},
+                "group": {"type": "string"},
+                "file_path": {"type": "string"},
+                "folder_path": {"type": "string"},
                 "permission": {"type": "string"},
                 "requires": {"type": "list", "schema": {"type": "string"}},
                 "url": {"type": "string"},
                 "version": {"type": "string", "coerce": str},
                 "source": {"type": "string"},
-                "target": {"type": "string"},
+                "dest": {"type": "string"},
                 "symbolic": {"type": "boolean"},
             },
         },
